@@ -151,8 +151,7 @@ protected:
 public:
   // Invalidate whole window.
   void invalidate() {
-    GtkAllocation allocation = get_allocation();
-    get_window()->invalidate_rect(Gdk::Rectangle(&allocation), false);
+    get_window()->invalidate_rect(get_allocation(), false);
   }
 
   // Update window synchronously (fast).
@@ -161,7 +160,7 @@ public:
 
 protected:
   // idle signal connection:
-  SigC::Connection m_ConnectionIdle;
+  sigc::connection m_ConnectionIdle;
 
 public:
   // get & set view rotation values.
@@ -207,7 +206,7 @@ GearsScene::GearsScene(bool is_sync)
   glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB    |
                                      Gdk::GL::MODE_DEPTH  |
                                      Gdk::GL::MODE_DOUBLE);
-  if (glconfig.is_null())
+  if (!glconfig)
     {
       std::cerr << "*** Cannot find the double-buffered visual.\n"
                 << "*** Trying single-buffered visual.\n";
@@ -215,7 +214,7 @@ GearsScene::GearsScene(bool is_sync)
       // Try single-buffered visual
       glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB   |
                                          Gdk::GL::MODE_DEPTH);
-      if (glconfig.is_null())
+      if (!glconfig)
         {
           std::cerr << "*** Cannot find any OpenGL-capable visual.\n";
           std::exit(1);
@@ -544,7 +543,7 @@ bool GearsScene::on_map_event(GdkEventAny* event)
 {
   if (!m_ConnectionIdle.connected())
     m_ConnectionIdle = Glib::signal_idle().connect(
-      SigC::slot(*this, &GearsScene::on_idle), GDK_PRIORITY_REDRAW);
+      sigc::mem_fun(*this, &GearsScene::on_idle), GDK_PRIORITY_REDRAW);
 
   return true;
 }
@@ -568,7 +567,7 @@ bool GearsScene::on_visibility_notify_event(GdkEventVisibility* event)
     {
       if (!m_ConnectionIdle.connected())
         m_ConnectionIdle = Glib::signal_idle().connect(
-          SigC::slot(*this, &GearsScene::on_idle), GDK_PRIORITY_REDRAW);
+          sigc::mem_fun(*this, &GearsScene::on_idle), GDK_PRIORITY_REDRAW);
     }
 
   return true;
@@ -640,7 +639,7 @@ Gears::Gears(bool is_sync)
   //
 
   m_ButtonQuit.signal_clicked().connect(
-    SigC::slot(*this, &Gears::on_button_quit_clicked));
+    sigc::mem_fun(*this, &Gears::on_button_quit_clicked));
 
   m_VBox.pack_start(m_ButtonQuit, Gtk::PACK_SHRINK, 0);
 
