@@ -504,14 +504,14 @@ namespace Logo
     glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB    |
                                        Gdk::GL::MODE_DEPTH  |
                                        Gdk::GL::MODE_DOUBLE);
-    if (glconfig.is_null()) {
+    if (!glconfig) {
       std::cerr << "*** Cannot find the double-buffered visual.\n"
                 << "*** Trying single-buffered visual.\n";
 
       // Try single-buffered visual
       glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB   |
                                          Gdk::GL::MODE_DEPTH);
-      if (glconfig.is_null()) {
+      if (!glconfig) {
         std::cerr << "*** Cannot find any OpenGL-capable visual.\n";
         std::exit(1);
       }
@@ -536,9 +536,9 @@ namespace Logo
 
     // View transformation signals.
     signal_button_press_event().connect(
-      SigC::bind(SigC::slot(m_View, &View::on_button_press_event), this));
+      sigc::bind(sigc::mem_fun(m_View, &View::on_button_press_event), this));
     signal_motion_notify_event().connect(
-      SigC::bind(SigC::slot(m_View, &View::on_motion_notify_event), this));
+      sigc::bind(sigc::mem_fun(m_View, &View::on_motion_notify_event), this));
 
     //
     // Popup menu.
@@ -702,7 +702,7 @@ namespace Logo
   {
     if (!m_ConnectionTimeout.connected())
       m_ConnectionTimeout = Glib::signal_timeout().connect(
-        SigC::slot(*this, &Scene::on_timeout), TIMEOUT_INTERVAL);
+        sigc::mem_fun(*this, &Scene::on_timeout), TIMEOUT_INTERVAL);
   }
 
   void Scene::timeout_remove()
@@ -738,15 +738,15 @@ namespace Logo
 
     // Toggle animation
     menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Toggle Animation",
-      SigC::slot(*this, &Scene::toggle_anim)));
+      sigc::mem_fun(*this, &Scene::toggle_anim)));
 
     // Init orientation
     menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Initialize",
-      SigC::slot(*this, &Scene::init_anim)));
+      sigc::mem_fun(*this, &Scene::init_anim)));
 
     // Quit
     menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Quit",
-      SigC::slot(&Gtk::Main::quit)));    
+      sigc::ptr_fun(&Gtk::Main::quit)));    
 
     return menu;
   }
@@ -786,7 +786,7 @@ namespace Logo
     //
 
     m_ButtonQuit.signal_clicked().connect(
-      SigC::slot(*this, &Application::on_button_quit_clicked));
+      sigc::mem_fun(*this, &Application::on_button_quit_clicked));
 
     m_VBox.pack_start(m_ButtonQuit, Gtk::PACK_SHRINK, 0);
 
