@@ -242,12 +242,17 @@ namespace Shapes
   bool View::on_button_press_event(GdkEventButton* event,
                                    Scene* scene)
   {
-    if (event->button == 1) {
-      if (is_animate()) {
+    if (is_animate()) {
+      if (event->button == 1) {
         disable_animation();
         scene->idle_remove();
-        scene->queue_draw();
+        scene->invalidate();
       }
+    } else {
+      m_QuatDiff[0] = 0.0;
+      m_QuatDiff[1] = 0.0;
+      m_QuatDiff[2] = 0.0;
+      m_QuatDiff[3] = 1.0;
     }
 
     m_BeginX = event->x;
@@ -260,8 +265,8 @@ namespace Shapes
   bool View::on_button_release_event(GdkEventButton* event,
                                      Scene* scene)
   {
-    if (event->button == 1) {
-      if (!is_animate() &&
+    if (!is_animate()) {
+      if (event->button == 1 &&
           ((m_DX*m_DX + m_DY*m_DY) > ANIMATE_THRESHOLD)) {
         enable_animation();
         scene->idle_add();
@@ -313,7 +318,7 @@ namespace Shapes
     m_BeginY = y;
 
     if (redraw)
-      scene->queue_draw();
+      scene->invalidate();
 
     // don't block
     return false;
@@ -542,14 +547,14 @@ namespace Shapes
     glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB    |
                                        Gdk::GL::MODE_DEPTH  |
                                        Gdk::GL::MODE_DOUBLE);
-    if (glconfig.is_null()) {
+    if (!glconfig) {
       std::cerr << "*** Cannot find the double-buffered visual.\n"
                 << "*** Trying single-buffered visual.\n";
 
       // Try single-buffered visual
       glconfig = Gdk::GL::Config::create(Gdk::GL::MODE_RGB   |
                                          Gdk::GL::MODE_DEPTH);
-      if (glconfig.is_null()) {
+      if (!glconfig) {
         std::cerr << "*** Cannot find any OpenGL-capable visual.\n";
         std::exit(1);
       }
@@ -575,11 +580,11 @@ namespace Shapes
 
     // View transformation signals.
     signal_button_press_event().connect(
-      SigC::bind(SigC::slot(m_View, &View::on_button_press_event), this));
+      sigc::bind(sigc::mem_fun(m_View, &View::on_button_press_event), this));
     signal_button_release_event().connect(
-      SigC::bind(SigC::slot(m_View, &View::on_button_release_event), this));
+      sigc::bind(sigc::mem_fun(m_View, &View::on_button_release_event), this));
     signal_motion_notify_event().connect(
-      SigC::bind(SigC::slot(m_View, &View::on_motion_notify_event), this));
+      sigc::bind(sigc::mem_fun(m_View, &View::on_motion_notify_event), this));
 
     //
     // Popup menu.
@@ -726,7 +731,10 @@ namespace Shapes
 
   bool Scene::on_idle()
   {
-    queue_draw();
+    // Invalidate whole window.
+    invalidate();
+    // Update window synchronously (fast).
+    update();
 
     return true;
   }
@@ -735,7 +743,7 @@ namespace Shapes
   {
     if (!m_ConnectionIdle.connected())
       m_ConnectionIdle = Glib::signal_idle().connect(
-        SigC::slot(*this, &Scene::on_idle), GDK_PRIORITY_REDRAW);
+        sigc::mem_fun(*this, &Scene::on_idle), GDK_PRIORITY_REDRAW);
   }
 
   void Scene::idle_remove()
@@ -765,47 +773,47 @@ namespace Shapes
 
       // Cube
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Cube",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_CUBE)));
 
       // Sphere
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Sphere",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_SPHERE)));
 
       // Cone
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Cone",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_CONE)));
 
       // Torus
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Torus",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_TORUS)));
 
       // Tetrahedron
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Tetrahedron",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_TETRAHEDRON)));
 
       // Octahedron
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Octahedron",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_OCTAHEDRON)));
 
       // Dodecahedron
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Dodecahedron",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_DODECAHEDRON)));
 
       // Icosahedron
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Icosahedron",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_ICOSAHEDRON)));
 
       // Teapot
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Teapot",
-        SigC::bind(SigC::slot(*this, &Scene::change_shape),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_shape),
                    Model::SHAPE_TEAPOT)));
 
     }
@@ -817,62 +825,62 @@ namespace Shapes
 
       // Emerald
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Emerald",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_EMERALD)));
 
       // Jade
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Jade",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_JADE)));
 
       // Obsidian
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Obsidian",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_OBSIDIAN)));
 
       // Pearl
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Pearl",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_PEARL)));
 
       // Ruby
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Ruby",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_RUBY)));
 
       // Turquoise
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Turquoise",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_TURQUOISE)));
 
       // Brass
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Brass",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_BRASS)));
 
       // Bronze
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Bronze",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_BRONZE)));
 
       // Chrome
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Chrome",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_CHROME)));
 
       // Copper
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Copper",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_COPPER)));
 
       // Gold
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Gold",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_GOLD)));
 
       // Silver
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Silver",
-        SigC::bind(SigC::slot(*this, &Scene::change_material),
+        sigc::bind(sigc::mem_fun(*this, &Scene::change_material),
                    &Model::MAT_SILVER)));
 
     }
@@ -892,7 +900,7 @@ namespace Shapes
 
       // Quit
       menu_list.push_back(Gtk::Menu_Helpers::MenuElem("Quit",
-        SigC::slot(&Gtk::Main::quit)));
+        sigc::ptr_fun(&Gtk::Main::quit)));
     }
 
     return menu;
@@ -914,10 +922,6 @@ namespace Shapes
 
     set_title(APP_NAME);
 
-#ifndef G_OS_WIN32
-    // Perform the resizes immediately.
-    set_resize_mode(Gtk::RESIZE_IMMEDIATE);
-#endif
     // Get automatically redrawn if any of their children changed allocation.
     set_reallocate_redraws(true);
 
@@ -936,7 +940,7 @@ namespace Shapes
     //
 
     m_ButtonQuit.signal_clicked().connect(
-      SigC::slot(*this, &Application::on_button_quit_clicked));
+      sigc::mem_fun(*this, &Application::on_button_quit_clicked));
 
     m_VBox.pack_start(m_ButtonQuit, Gtk::PACK_SHRINK, 0);
 
@@ -966,7 +970,7 @@ namespace Shapes
       return true;
     }
 
-    m_Scene.queue_draw();
+    m_Scene.invalidate();
 
     return true;
   }
